![Paithon Logo](https://raw.githubusercontent.com/MarcSkovMadsen/paithon/main/assets/images/paithon-logo.png)

[![PyPI version](https://badge.fury.io/py/paithon.svg)](https://pypi.org/project/paithon/) [![Downloads](https://pepy.tech/badge/paithon/month)](https://pepy.tech/project/paithon) ![Python Versions](https://img.shields.io/badge/python-3.6%20%7C%203.7%20%7C%203.8%20%7C%203.9-blue) ![PyPI - License](https://img.shields.io/pypi/l/paithon) ![Style Black](https://warehouse-camo.ingress.cmh1.psfhosted.org/fbfdc7754183ecf079bc71ddeabaf88f6cbc5c00/68747470733a2f2f696d672e736869656c64732e696f2f62616467652f636f64652532307374796c652d626c61636b2d3030303030302e737667)

[![Follow on Twitter](https://img.shields.io/twitter/follow/MarcSkovMadsen.svg?style=social)](https://twitter.com/MarcSkovMadsen)

# &#129504; Paithon

PRE-ALPHA STATE

**Visualize, communicate and share your AI models in no time**.

Easy to use AI components, tools and examples for the Jupyter Notebook, your favorite Editor/ IDE and your next AI App.

*Paithon* is the abbreviation of "Panel AI Tools with Humor ON".

Get started in your favorite environment

| Jupyter Notebook | Jupyter Labs | Panel Apps |
| - | - | - |
| [![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/marcskovmadsen/paithon/HEAD?filepath=examples) | [![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/marcskovmadsen/paithon/HEAD?urlpath=lab/tree/examples) | [![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/marcskovmadsen/paithon/HEAD?urlpath=panel) |

## 🏁 Background

I believe that Panel is a very flexible and powerful tool compared to the other python ML app frameworks out there. I believe it can give you and your AI team super powers.

So I started this project to help you and to learn more about AI.

## ⚖️ License

The `paithon` package and repository is open source and free to use (MIT License).

## 🏃 Getting Started

With `pip`

```bash
pip install paithon
```

From within a Jupyter Notebook

```python
import paithon as pa
import panel as pn

pn.extension()
```

### 👩‍🏫 Reference Guides

| Guide | Notebook | Jupyter Notebook | Jupyter Labs | Panel App |
| - | - | - | - | - |
| HighChart | [View](https://github.com/MarcSkovMadsen/paithon/blob/main/examples/HighChart.ipynb) | [![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/marcskovmadsen/paithon/HEAD?filepath=examples/HighChart.ipynb) | [![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/marcskovmadsen/paithon/HEAD?urlpath=lab/tree/examples/HighChart.ipynb) | [![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/marcskovmadsen/paithon/HEAD?urlpath=panel/HighChart) |

### 🎨 Gallery

| Guide | Notebook | Jupyter Notebook | Jupyter Labs | App | App
| - | - | - | - |- | - |
| AddSeriesDynamically | [View](https://github.com/MarcSkovMadsen/paithon/blob/main/examples/AddSeriesDynamically.ipynb) | [![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/marcskovmadsen/paithon/HEAD?filepath=examples/AddSeriesDynamically.ipynb) | [![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/marcskovmadsen/paithon/HEAD?urlpath=lab/tree/examples/AddSeriesDynamically.ipynb) | [![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/marcskovmadsen/paithon/HEAD?urlpath=panel/AddSeriesDynamically) | |

## 💡 Inspiration

I find inspiration at

- [Hugging Face Widgets](https://github.com/huggingface/huggingface_hub/tree/main/widgets)
- [Gradio](https://gradio.app/)
- [Panel](https://panel.holoviz.org)

## 🛣️ Roadmap

When I get the time I would like to

- Support common workflows in ML and DL.
- Implement Panel versions of the Hugging Face widgets
- Show that Panel can easily do what Gradio can and so much more.
- Add badges for 100% test coverage etc.
- Distribute as conda package

## 📰 Change Log

- 0.0.1: First Version
